@@ -52,7 +52,7 @@
 #include "ogr_spatialref.h"
 #include "vrtdataset.h"
 
-CPL_CVSID("$Id: gdal_translate_lib.cpp 37719 2017-03-16 14:51:42Z rouault $");
+CPL_CVSID("$Id: gdal_translate_lib.cpp 40479 2017-10-17 22:52:41Z rouault $");
 
 static int ArgIsNumeric( const char * );
 static void AttachMetadata( GDALDatasetH, char ** );
@@ -1221,16 +1221,20 @@ GDALDatasetH GDALTranslate( const char *pszDest, GDALDatasetH hSrcDataset,
 /* -------------------------------------------------------------------- */
 /*      Select output data type to match source.                        */
 /* -------------------------------------------------------------------- */
+        GDALRasterBand* poRealSrcBand =
+                (nSrcBand < 0) ? poSrcBand->GetMaskBand(): poSrcBand;
         if( psOptions->eOutputType == GDT_Unknown )
-            eBandType = poSrcBand->GetRasterDataType();
+        {
+            eBandType = poRealSrcBand->GetRasterDataType();
+        }
         else
         {
             eBandType = psOptions->eOutputType;
 
             // Check that we can copy existing statistics
-            GDALDataType eSrcBandType = poSrcBand->GetRasterDataType();
-            const char* pszMin = poSrcBand->GetMetadataItem("STATISTICS_MINIMUM");
-            const char* pszMax = poSrcBand->GetMetadataItem("STATISTICS_MAXIMUM");
+            GDALDataType eSrcBandType = poRealSrcBand->GetRasterDataType();
+            const char* pszMin = poRealSrcBand->GetMetadataItem("STATISTICS_MINIMUM");
+            const char* pszMax = poRealSrcBand->GetMetadataItem("STATISTICS_MAXIMUM");
             if( !bFilterOutStatsMetadata && eBandType != eSrcBandType &&
                 pszMin != NULL && pszMax != NULL )
             {
@@ -1488,13 +1492,7 @@ GDALDatasetH GDALTranslate( const char *pszDest, GDALDatasetH hSrcDataset,
                 bSignedByte = true;
             int bClamped = FALSE, bRounded = FALSE;
             double dfVal;
-            if( eBandType == GDT_Float32 && CPLIsInf(psOptions->dfNoDataReal) )
-            {
-                dfVal = std::numeric_limits<float>::infinity();
-                if( psOptions->dfNoDataReal < 0 )
-                    dfVal = -dfVal;
-            }
-            else if( bSignedByte )
+            if( bSignedByte )
             {
                 if( psOptions->dfNoDataReal < -128 )
                 {
