@@ -1,14 +1,13 @@
 /******************************************************************************
- * $Id: coasp_dataset.cpp 33720 2016-03-15 00:39:53Z goatbar $
  *
  * Project:  DRDC Configurable Airborne SAR Processor (COASP) data reader
  * Purpose:  Support in GDAL for the DRDC COASP format data, both Metadata
- *	     and complex imagery.
+ *           and complex imagery.
  * Author:   Philippe Vachon <philippe@cowpig.ca>
  * Notes:    I have seen a grand total of 2 COASP scenes (3 sets of headers).
- *	     This is based on my best observations, some educated guesses and
- *	     such. So if you have a scene that doesn't work, send it to me
- *	     please and I will make it work... with violence.
+ *           This is based on my best observations, some educated guesses and
+ *           such. So if you have a scene that doesn't work, send it to me
+ *           please and I will make it work... with violence.
  *
  ******************************************************************************
  * Copyright (c) 2007, Philippe Vachon
@@ -40,16 +39,16 @@
 #include "gdal_frmts.h"
 #include "gdal_priv.h"
 
-CPL_CVSID("$Id: coasp_dataset.cpp 33720 2016-03-15 00:39:53Z goatbar $");
+CPL_CVSID("$Id: coasp_dataset.cpp 36501 2016-11-25 14:09:24Z rouault $");
 
 static const int TYPE_GENERIC = 0;
 static const int TYPE_GEOREF = 1;
 
 enum ePolarization {
-	hh = 0,
-	hv,
-	vh,
-	vv
+    hh = 0,
+    hv,
+    vh,
+    vv
 };
 
 /*******************************************************************
@@ -60,18 +59,18 @@ class COASPMetadataItem;
 
 class COASPMetadataReader
 {
-	VSILFILE *fp;
-	char **papszMetadata;
-	int nMetadataCount;
-	int nCurrentItem;
+        VSILFILE *fp;
+        char **papszMetadata;
+        int nMetadataCount;
+        int nCurrentItem;
 public:
-	COASPMetadataReader(char *pszFname);
+        explicit COASPMetadataReader(char *pszFname);
         ~COASPMetadataReader();
-	COASPMetadataItem *GetNextItem();
-	COASPMetadataItem *GetItem(int nItem);
-	int GotoMetadataItem(int nItemNumber);
-	int GotoMetadataItem(const char *pszName);
-	int GetCurrentItem() { return nCurrentItem; }
+        COASPMetadataItem *GetNextItem();
+        COASPMetadataItem *GetItem(int nItem);
+        int GotoMetadataItem(int nItemNumber);
+        int GotoMetadataItem(const char *pszName);
+        int GetCurrentItem() { return nCurrentItem; }
 };
 
 /* Your average metadata item */
@@ -88,7 +87,7 @@ public:
 
     char *GetItemName();
     char *GetItemValue();
-    int GetType() { return TYPE_GENERIC; }
+    static int GetType() { return TYPE_GENERIC; }
 };
 
 /* Same as MetadataItem class except parses GCP properly and returns
@@ -96,18 +95,20 @@ public:
  */
 class COASPMetadataGeorefGridItem : public COASPMetadataItem
 {
-	int nId;
-	int nPixels;
-	int nLines;
-	double ndLat;
-	double ndLong;
+#ifdef unused
+        int nId;
+        int nPixels;
+        int nLines;
+        double ndLat;
+        double ndLong;
+#endif
 
 public:
-	COASPMetadataGeorefGridItem(int nId, int nPixels, int nLines,
-		double ndLat, double ndLong);
-	const char *GetItemName() { return "georef_grid"; }
-	GDAL_GCP *GetItemValue();
-	int GetType() { return TYPE_GEOREF; }
+        COASPMetadataGeorefGridItem( int nId, int nPixels, int nLines,
+                                     double ndLat, double ndLong );
+        static const char *GetItemName() { return "georef_grid"; }
+        GDAL_GCP *GetItemValue();
+        static int GetType() { return TYPE_GEOREF; }
 };
 
 /********************************************************************
@@ -116,11 +117,10 @@ public:
  * ================================================================ *
  ********************************************************************/
 
-COASPMetadataItem::COASPMetadataItem(char *pszItemName_, char *pszItemValue_)
-{
-    pszItemName = VSIStrdup(pszItemName_);
-    pszItemValue = VSIStrdup(pszItemValue_);
-}
+COASPMetadataItem::COASPMetadataItem(char *pszItemName_, char *pszItemValue_) :
+    pszItemName(VSIStrdup(pszItemName_)),
+    pszItemValue(VSIStrdup(pszItemValue_))
+{}
 
 COASPMetadataItem::~COASPMetadataItem()
 {
@@ -130,28 +130,32 @@ COASPMetadataItem::~COASPMetadataItem()
 
 char *COASPMetadataItem::GetItemName()
 {
-	return VSIStrdup(pszItemName);
+        return VSIStrdup(pszItemName);
 }
 
 char *COASPMetadataItem::GetItemValue()
 {
-	return VSIStrdup(pszItemValue);
+        return VSIStrdup(pszItemValue);
 }
 
-COASPMetadataGeorefGridItem::COASPMetadataGeorefGridItem(int nIdIn, int nPixelsIn,
-	int nLinesIn, double ndLatIn, double ndLongIn)
+COASPMetadataGeorefGridItem::COASPMetadataGeorefGridItem(
+    int /*nIdIn*/, int /*nPixelsIn*/,
+    int /*nLinesIn*/, double /*ndLatIn*/, double /*ndLongIn*/ )
+#ifdef unused
+:
+    nId(nIdIn),
+    nPixels(nPixelsIn),
+    nLines(nLinesIn),
+    ndLat(ndLatIn),
+    ndLong(ndLongIn)
+#endif
 {
-	this->nId = nIdIn;
-	this->nPixels = nPixelsIn;
-	this->nLines = nLinesIn;
-	this->ndLat = ndLatIn;
-	this->ndLong = ndLongIn;
-        pszItemName = VSIStrdup("georef_grid");
+    pszItemName = VSIStrdup("georef_grid");
 }
 
 GDAL_GCP *COASPMetadataGeorefGridItem::GetItemValue()
 {
-	return NULL;
+    return NULL;
 }
 
 /********************************************************************
@@ -161,9 +165,11 @@ GDAL_GCP *COASPMetadataGeorefGridItem::GetItemValue()
  ********************************************************************/
 
 COASPMetadataReader::COASPMetadataReader(char *pszFname) :
-    fp(NULL), papszMetadata(NULL), nMetadataCount(0), nCurrentItem(0)
+    fp(NULL),
+    papszMetadata(CSLLoad(pszFname)),
+    nMetadataCount(0),
+    nCurrentItem(0)
 {
-    papszMetadata = CSLLoad(pszFname);
     nMetadataCount = CSLCount(papszMetadata);
 }
 
@@ -176,69 +182,70 @@ COASPMetadataReader::~COASPMetadataReader()
 
 COASPMetadataItem *COASPMetadataReader::GetNextItem()
 {
-	if (nCurrentItem >= nMetadataCount)
-		return NULL;
+        if (nCurrentItem >= nMetadataCount)
+            return NULL;
 
-        COASPMetadataItem *poMetadata;
+        COASPMetadataItem *poMetadata = NULL;
 
         char **papszMDTokens
             = CSLTokenizeString2(papszMetadata[nCurrentItem], " ",
                                  CSLT_HONOURSTRINGS );
         char *pszItemName = papszMDTokens[0];
-	if (STARTS_WITH_CI(pszItemName, "georef_grid")) {
-		// georef_grid ( pixels lines ) ( lat long )
-		// 0           1 2      3     4 5 6   7    8
-                int nPixels = atoi(papszMDTokens[2]);
-                int nLines = atoi(papszMDTokens[3]);
-                double dfLat = CPLAtof(papszMDTokens[6]);
-                double dfLong = CPLAtof(papszMDTokens[7]);
-                poMetadata = new COASPMetadataGeorefGridItem(
-                    nCurrentItem, nPixels, nLines, dfLat, dfLong);
-	}
-	else {
-		int nCount = CSLCount(papszMDTokens);
-                char *pszItemValue = CPLStrdup(papszMDTokens[1]);
-		for (int i = 2; i < nCount; i++) {
-			const size_t nSize = strlen(pszItemValue) + 1 + strlen(papszMDTokens[i]);
-			pszItemValue = (char *)CPLRealloc(pszItemValue, nSize);
-			snprintf(pszItemValue + strlen(pszItemValue),
-                                 nSize - strlen(pszItemValue), " %s",
-				papszMDTokens[i]);
-		}
+        if (STARTS_WITH_CI(pszItemName, "georef_grid"))
+        {
+            // georef_grid ( pixels lines ) ( lat long )
+            // 0           1 2      3     4 5 6   7    8
+            int nPixels = atoi(papszMDTokens[2]);
+            int nLines = atoi(papszMDTokens[3]);
+            double dfLat = CPLAtof(papszMDTokens[6]);
+            double dfLong = CPLAtof(papszMDTokens[7]);
+            poMetadata = new COASPMetadataGeorefGridItem(
+                nCurrentItem, nPixels, nLines, dfLat, dfLong);
+        }
+        else
+        {
+            int nCount = CSLCount(papszMDTokens);
+            char *pszItemValue = CPLStrdup(papszMDTokens[1]);
+            for (int i = 2; i < nCount; i++)
+            {
+                const size_t nSize = strlen(pszItemValue) + 1 + strlen(papszMDTokens[i]);
+                pszItemValue = (char *)CPLRealloc(pszItemValue, nSize);
+                snprintf(pszItemValue + strlen(pszItemValue),
+                         nSize - strlen(pszItemValue), " %s",
+                         papszMDTokens[i]);
+            }
 
-		poMetadata = new COASPMetadataItem(pszItemName,
-			pszItemValue);
+            poMetadata = new COASPMetadataItem(pszItemName, pszItemValue);
 
-		CPLFree(pszItemValue);
-	}
-	CSLDestroy(papszMDTokens);
-	nCurrentItem++;
-	return poMetadata;
+            CPLFree(pszItemValue);
+        }
+        CSLDestroy(papszMDTokens);
+        nCurrentItem++;
+        return poMetadata;
 }
 
 /* Goto a particular metadata item, listed by number */
 int COASPMetadataReader::GotoMetadataItem(int nItemNumber)
 {
-	if (nItemNumber >= nMetadataCount || nItemNumber < 0) {
+        if (nItemNumber >= nMetadataCount || nItemNumber < 0) {
             nCurrentItem = 0;
-	}
-	else
+        }
+        else
             nCurrentItem = nItemNumber;
-	return nCurrentItem;
+        return nCurrentItem;
 }
 
 /* Goto the first metadata item with a particular name */
 int COASPMetadataReader::GotoMetadataItem(const char *pszName)
 {
-	nCurrentItem = CSLPartialFindString(papszMetadata, pszName);
-	return nCurrentItem;
+        nCurrentItem = CSLPartialFindString(papszMetadata, pszName);
+        return nCurrentItem;
 }
 
 /*******************************************************************
  * Declaration of the COASPDataset class                           *
  *******************************************************************/
 
-
 class COASPRasterBand;
 
 /* A couple of observations based on the data I have available to me:
@@ -253,22 +260,32 @@ class COASPRasterBand;
 
 class COASPDataset : public GDALDataset
 {
-	friend class COASPRasterBand;
-	VSILFILE *fpHdr; /* File pointer for the header file */
-	VSILFILE *fpBinHH; /* File pointer for the binary matrix */
-	VSILFILE *fpBinHV;
-	VSILFILE *fpBinVH;
-	VSILFILE *fpBinVV;
+        friend class COASPRasterBand;
+        VSILFILE *fpHdr; /* File pointer for the header file */
+        VSILFILE *fpBinHH; /* File pointer for the binary matrix */
+        VSILFILE *fpBinHV;
+        VSILFILE *fpBinVH;
+        VSILFILE *fpBinVV;
 
-	char *pszFileName; /* line and mission ID, mostly, i.e. l27p7 */
+        char *pszFileName; /* line and mission ID, mostly, i.e. l27p7 */
 
-	int nGCPCount;
-	GDAL_GCP *pasGCP;
+        int nGCPCount;
+        GDAL_GCP *pasGCP;
 public:
-	static GDALDataset *Open( GDALOpenInfo * );
-	static int Identify( GDALOpenInfo * poOpenInfo );
-	int GetGCPCount();
-	const GDAL_GCP *GetGCPs();
+        COASPDataset():
+            fpHdr(NULL),
+            fpBinHH(NULL),
+            fpBinHV(NULL),
+            fpBinVH(NULL),
+            fpBinVV(NULL),
+            pszFileName(NULL),
+            nGCPCount(0),
+            pasGCP(NULL) {}
+
+        static GDALDataset *Open( GDALOpenInfo * );
+        static int Identify( GDALOpenInfo * poOpenInfo );
+        int GetGCPCount() override;
+        const GDAL_GCP *GetGCPs() override;
 };
 
 /********************************************************************
@@ -278,21 +295,23 @@ public:
  ********************************************************************/
 
 class COASPRasterBand : public GDALRasterBand {
-	VSILFILE *fp;
-	int ePol;
+        VSILFILE *fp;
+        /*int ePol;*/
 public:
-	COASPRasterBand( COASPDataset *poDS, GDALDataType eDataType, int ePol, VSILFILE *fp );
-	virtual CPLErr IReadBlock( int nBlockXOff, int nBlockYOff,
-		void *pImage);
+        COASPRasterBand( COASPDataset *poDS, GDALDataType eDataType,
+                         int ePol, VSILFILE *fp );
+        virtual CPLErr IReadBlock( int nBlockXOff, int nBlockYOff,
+                                   void *pImage) override;
 };
 
-COASPRasterBand::COASPRasterBand( COASPDataset *poDSIn, GDALDataType eDataTypeIn,
-	int ePolIn, VSILFILE *fpIn)
+COASPRasterBand::COASPRasterBand( COASPDataset *poDSIn,
+                                  GDALDataType eDataTypeIn,
+                                  int /*ePolIn*/, VSILFILE *fpIn ) :
+        fp(fpIn)/*,
+        ePol(ePolIn)*/
 {
-	this->fp = fpIn;
-	this->ePol = ePolIn;
-	this->poDS = poDSIn;
-	this->eDataType = eDataTypeIn;
+        poDS = poDSIn;
+        eDataType = eDataTypeIn;
         nBlockXSize = poDS->GetRasterXSize();
         nBlockYSize = 1;
 }
@@ -301,26 +320,26 @@ CPLErr COASPRasterBand::IReadBlock( CPL_UNUSED int nBlockXOff,
                                     int nBlockYOff,
                                     void *pImage )
 {
-	if (this->fp == NULL) {
-		CPLError(CE_Fatal, CPLE_AppDefined, "file pointer freed unexpectedly\n");
-		return CE_Fatal;
-	}
+        if (this->fp == NULL)
+        {
+            CPLError(CE_Fatal, CPLE_AppDefined,
+                     "File pointer freed unexpectedly");
+            return CE_Fatal;
+        }
 
-	/* 8 bytes per pixel: 4 bytes I, 4 bytes Q */
-	unsigned long nByteNum = poDS->GetRasterXSize() * 8 * nBlockYOff;
+        /* 8 bytes per pixel: 4 bytes I, 4 bytes Q */
+        unsigned long nByteNum = poDS->GetRasterXSize() * 8 * nBlockYOff;
 
-	VSIFSeekL(this->fp, nByteNum, SEEK_SET);
-	int nReadSize = (GDALGetDataTypeSize(eDataType)/8) * poDS->GetRasterXSize();
-	VSIFReadL((char *)pImage, 1, nReadSize,
-		this->fp);
+        VSIFSeekL(this->fp, nByteNum, SEEK_SET);
+        int nReadSize = (GDALGetDataTypeSize(eDataType)/8) * poDS->GetRasterXSize();
+        VSIFReadL((char *)pImage, 1, nReadSize, this->fp);
 
 #ifdef CPL_LSB
-	GDALSwapWords( pImage, 4, nBlockXSize * 2, 4 );
+        GDALSwapWords( pImage, 4, nBlockXSize * 2, 4 );
 #endif
-	return CE_None;
+        return CE_None;
 }
 
-
 /********************************************************************
  * ================================================================ *
  * Implementation of the COASPDataset Class                         *
@@ -333,7 +352,7 @@ CPLErr COASPRasterBand::IReadBlock( CPL_UNUSED int nBlockXOff,
 
 int COASPDataset::GetGCPCount()
 {
-	return nGCPCount;
+        return nGCPCount;
 }
 
 /************************************************************************/
@@ -342,7 +361,7 @@ int COASPDataset::GetGCPCount()
 
 const GDAL_GCP *COASPDataset::GetGCPs()
 {
-	return pasGCP;
+        return pasGCP;
 }
 
 /************************************************************************/
@@ -351,16 +370,15 @@ const GDAL_GCP *COASPDataset::GetGCPs()
 
 int COASPDataset::Identify( GDALOpenInfo *poOpenInfo )
 {
-	if(poOpenInfo->fpL == NULL || poOpenInfo->nHeaderBytes < 256)
-		return 0;
+    if(poOpenInfo->fpL == NULL || poOpenInfo->nHeaderBytes < 256)
+        return 0;
 
-	/* With a COASP .hdr file, the first line or so is:
- 	 * time_first_datarec
- 	 */
-	if(STARTS_WITH_CI((char *)poOpenInfo->pabyHeader, "time_first_datarec"))
-		return 1;
+    // With a COASP .hdr file, the first line or so is: time_first_datarec
 
-	return 0;
+    if(STARTS_WITH_CI((char *)poOpenInfo->pabyHeader, "time_first_datarec"))
+        return 1;
+
+    return 0;
 }
 
 /************************************************************************/
@@ -369,8 +387,8 @@ int COASPDataset::Identify( GDALOpenInfo *poOpenInfo )
 
 GDALDataset *COASPDataset::Open( GDALOpenInfo *poOpenInfo )
 {
-	if (!COASPDataset::Identify(poOpenInfo))
-		return NULL;
+    if (!COASPDataset::Identify(poOpenInfo))
+        return NULL;
 
 /* -------------------------------------------------------------------- */
 /*      Confirm the requested access is supported.                      */
@@ -386,52 +404,57 @@ GDALDataset *COASPDataset::Open( GDALOpenInfo *poOpenInfo )
     /* Create a fresh dataset for us to work with */
     COASPDataset *poDS = new COASPDataset();
 
-	if (poDS == NULL)
-		return NULL;
+    if (poDS == NULL)
+        return NULL;
 
-	/* Steal the file pointer for the header */
-	poDS->fpHdr = poOpenInfo->fpL;
-	poOpenInfo->fpL = NULL;
+    /* Steal the file pointer for the header */
+    poDS->fpHdr = poOpenInfo->fpL;
+    poOpenInfo->fpL = NULL;
 
-	/* Set the binary matrix file pointers to NULL, for now */
-	poDS->fpBinHH = NULL;
-	poDS->fpBinHV = NULL;
-	poDS->fpBinVH = NULL;
-	poDS->fpBinVV = NULL;
-        poDS->nGCPCount = 0;
-        poDS->pasGCP = NULL;
+    /* Set the binary matrix file pointers to NULL, for now */
+    poDS->fpBinHH = NULL;
+    poDS->fpBinHV = NULL;
+    poDS->fpBinVH = NULL;
+    poDS->fpBinVV = NULL;
+    poDS->nGCPCount = 0;
+    poDS->pasGCP = NULL;
 
-	poDS->pszFileName = VSIStrdup(poOpenInfo->pszFilename);
+    poDS->pszFileName = VSIStrdup(poOpenInfo->pszFilename);
 
-	/* determine the file name prefix */
-	char *pszBaseName = VSIStrdup(CPLGetBasename(poDS->pszFileName));
-	char *pszDir = VSIStrdup(CPLGetPath(poDS->pszFileName));
-	const char *pszExt = "rc";
-	int nNull = static_cast<int>(strlen(pszBaseName)) - 1;
-	char *pszBase = (char *)CPLMalloc(nNull);
-	strncpy(pszBase, pszBaseName, nNull);
-	pszBase[nNull - 1] = '\0';
-	free(pszBaseName);
+    /* determine the file name prefix */
+    char *pszBaseName = VSIStrdup(CPLGetBasename(poDS->pszFileName));
+    char *pszDir = VSIStrdup(CPLGetPath(poDS->pszFileName));
+    const char *pszExt = "rc";
+    int nNull = static_cast<int>(strlen(pszBaseName)) - 1;
+    char *pszBase = (char *)CPLMalloc(nNull);
+    strncpy(pszBase, pszBaseName, nNull);
+    pszBase[nNull - 1] = '\0';
+    free(pszBaseName);
 
-	char *psChan = strstr(pszBase,"hh");;
-	if (psChan == NULL) {
-		psChan = strstr(pszBase, "hv");
-	}
-	if (psChan == NULL) {
-		psChan = strstr(pszBase, "vh");
-	}
-	if (psChan == NULL) {
-		psChan = strstr(pszBase, "vv");
-	}
+    char *psChan = strstr(pszBase,"hh");
+    if( psChan == NULL )
+    {
+        psChan = strstr(pszBase, "hv");
+    }
+    if (psChan == NULL)
+    {
+        psChan = strstr(pszBase, "vh");
+    }
+    if (psChan == NULL)
+    {
+        psChan = strstr(pszBase, "vv");
+    }
 
-	if (psChan == NULL) {
-		CPLError(CE_Fatal, CPLE_AppDefined, "unable to recognize file as COASP.\n");
-		free(poDS->pszFileName);
-		free(pszBase);
-		free(pszDir);
-		delete poDS;
-		return NULL;
-	}
+    if (psChan == NULL)
+    {
+        CPLError(CE_Fatal, CPLE_AppDefined,
+                 "Unable to recognize file as COASP.");
+        free(poDS->pszFileName);
+        free(pszBase);
+        free(pszDir);
+        delete poDS;
+        return NULL;
+    }
 
     /* Read Metadata, set GCPs as is appropriate */
     COASPMetadataReader *poReader = new COASPMetadataReader(
@@ -451,82 +474,84 @@ GDALDataset *COASPDataset::Open( GDALOpenInfo *poOpenInfo )
     poDS->nRasterXSize = atoi(nValue);
     free(nValue);
 
+    /* Horizontal transmit, horizontal receive */
+    psChan[0] = 'h';
+    psChan[1] = 'h';
+    const char *pszFilename = CPLFormFilename(pszDir, pszBase, pszExt);
 
-	/* Horizontal transmit, horizontal receive */
-	psChan[0] = 'h';
-	psChan[1] = 'h';
-     const char *pszFilename = CPLFormFilename(pszDir, pszBase, pszExt);
+    poDS->fpBinHH = VSIFOpenL(pszFilename, "r");
 
-	poDS->fpBinHH = VSIFOpenL(pszFilename, "r");
+    if (poDS->fpBinHH != NULL)
+    {
+        /* Set raster band */
+        poDS->SetBand(1, new COASPRasterBand(poDS, GDT_CFloat32,
+                                             hh , poDS->fpBinHH));
+    }
 
-	if (poDS->fpBinHH != NULL) {
-		/* Set raster band */
-		poDS->SetBand(1, new COASPRasterBand(poDS, GDT_CFloat32,
-			hh , poDS->fpBinHH));
-	}
-
-	/* Horizontal transmit, vertical receive */
+    /* Horizontal transmit, vertical receive */
     psChan[0] = 'h';
     psChan[1] = 'v';
     pszFilename = CPLFormFilename(pszDir, pszBase, pszExt);
 
-	poDS->fpBinHV = VSIFOpenL(pszFilename, "r");
+    poDS->fpBinHV = VSIFOpenL(pszFilename, "r");
 
-	if (poDS->fpBinHV != NULL) {
-		poDS->SetBand(2, new COASPRasterBand(poDS, GDT_CFloat32,
-			hv, poDS->fpBinHV));
-	}
+    if (poDS->fpBinHV != NULL)
+    {
+        poDS->SetBand(2, new COASPRasterBand(poDS, GDT_CFloat32,
+                                             hv, poDS->fpBinHV));
+    }
 
-	/* Vertical transmit, horizontal receive */
+    /* Vertical transmit, horizontal receive */
     psChan[0] = 'v';
     psChan[1] = 'h';
     pszFilename = CPLFormFilename(pszDir, pszBase, pszExt);
 
-	poDS->fpBinVH = VSIFOpenL(pszFilename, "r");
+    poDS->fpBinVH = VSIFOpenL(pszFilename, "r");
 
-	if (poDS->fpBinVH != NULL) {
-    	poDS->SetBand(3, new COASPRasterBand(poDS, GDT_CFloat32,
-			vh, poDS->fpBinVH));
-	}
+    if (poDS->fpBinVH != NULL)
+    {
+        poDS->SetBand(3, new COASPRasterBand(poDS, GDT_CFloat32,
+                                             vh, poDS->fpBinVH));
+    }
 
-	/* Vertical transmit, vertical receive */
+    /* Vertical transmit, vertical receive */
     psChan[0] = 'v';
     psChan[1] = 'v';
     pszFilename = CPLFormFilename(pszDir, pszBase, pszExt);
 
-	poDS->fpBinVV = VSIFOpenL(pszFilename, "r");
+    poDS->fpBinVV = VSIFOpenL(pszFilename, "r");
 
-	if (poDS->fpBinVV != NULL) {
-		poDS->SetBand(4, new COASPRasterBand(poDS, GDT_CFloat32,
-			vv, poDS->fpBinVV));
-	}
+    if (poDS->fpBinVV != NULL)
+    {
+        poDS->SetBand(4, new COASPRasterBand(poDS, GDT_CFloat32,
+                                             vv, poDS->fpBinVV));
+    }
 
+    /* Oops, missing all the data? */
+    if (poDS->fpBinHH == NULL && poDS->fpBinHV == NULL
+        && poDS->fpBinVH == NULL && poDS->fpBinVV == NULL)
+    {
+        CPLError(CE_Fatal,CPLE_AppDefined,"Unable to find any data! Aborting.");
+        free(pszBase);
+        free(pszDir);
+        delete poDS;
+        delete poItem;
+        delete poReader;
+        return NULL;
+    }
 
-	/* Oops, missing all the data? */
-
-	if (poDS->fpBinHH == NULL && poDS->fpBinHV == NULL
-		&& poDS->fpBinVH == NULL && poDS->fpBinVV == NULL)
-	{
-		CPLError(CE_Fatal,CPLE_AppDefined,"Unable to find any data! Aborting.");
-		free(pszBase);
-		free(pszDir);
-		delete poDS;
-                delete poItem;
-                delete poReader;
-		return NULL;
-	}
-
-    if ( poDS->GetRasterCount() == 4 ) {
+    if( poDS->GetRasterCount() == 4 )
+    {
         poDS->SetMetadataItem( "MATRIX_REPRESENTATION", "SCATTERING" );
     }
 
-	free(pszBase);
-	free(pszDir);
+    free(pszBase);
+    free(pszDir);
 
-	delete poItem;
-	delete poReader;
+    delete poItem;
+    delete poReader;
 
-	return poDS;
+    return poDS;
 }
 
 /************************************************************************/
