@@ -1,5 +1,4 @@
 /******************************************************************************
- * $Id: envisatdataset.cpp 33720 2016-03-15 00:39:53Z goatbar $
  *
  * Project:  APP ENVISAT Support
  * Purpose:  Reader for ENVISAT format image data.
@@ -35,7 +34,7 @@
 #include "ogr_srs_api.h"
 #include "timedelta.hpp"
 
-CPL_CVSID("$Id: envisatdataset.cpp 33720 2016-03-15 00:39:53Z goatbar $");
+CPL_CVSID("$Id: envisatdataset.cpp 39169 2017-06-18 13:48:09Z rouault $");
 
 CPL_C_START
 #include "EnvisatFile.h"
@@ -52,7 +51,7 @@ class MerisL2FlagBand : public GDALPamRasterBand
   public:
     MerisL2FlagBand( GDALDataset *, int, VSILFILE*, vsi_l_offset, int );
     virtual ~MerisL2FlagBand();
-    virtual CPLErr IReadBlock( int, int, void * );
+    virtual CPLErr IReadBlock( int, int, void * ) override;
 
   private:
     vsi_l_offset nImgOffset;
@@ -68,29 +67,30 @@ class MerisL2FlagBand : public GDALPamRasterBand
 /*                        MerisL2FlagBand()                       */
 /************************************************************************/
 MerisL2FlagBand::MerisL2FlagBand( GDALDataset *poDSIn, int nBandIn,
-                                  VSILFILE* fpImageIn, vsi_l_offset nImgOffsetIn,
+                                  VSILFILE* fpImageIn,
+                                  vsi_l_offset nImgOffsetIn,
                                   int nPrefixBytesIn ) :
-    nBytePerPixel(3)
+    nImgOffset(nImgOffsetIn),
+    nPrefixBytes(nPrefixBytesIn),
+    nBytePerPixel(3),
+    nRecordSize(0),
+    nDataSize(0),
+    pReadBuf(NULL)
 {
-    this->poDS = poDSIn;
-    this->nBand = nBandIn;
+    poDS = poDSIn;
+    nBand = nBandIn;
 
-    this->fpImage = fpImageIn;
-    this->nImgOffset = nImgOffsetIn;
-    this->nPrefixBytes = nPrefixBytesIn;
+    fpImage = fpImageIn;
 
     eDataType = GDT_UInt32;
 
     nBlockXSize = poDS->GetRasterXSize();
     nBlockYSize = 1;
-
+    nRecordSize = nPrefixBytesIn + nBlockXSize * nBytePerPixel;
     nDataSize = nBlockXSize * nBytePerPixel;
-    nRecordSize = nPrefixBytes + nDataSize;
-
-    pReadBuf = (GByte *) CPLMalloc( nRecordSize );
+    pReadBuf = static_cast<GByte *>(CPLMalloc(nRecordSize));
 }
 
-
 /************************************************************************/
 /*                        ~MerisL2FlagBand()                       */
 /************************************************************************/
@@ -128,9 +128,10 @@ CPLErr MerisL2FlagBand::IReadBlock( CPL_UNUSED int nBlockXOff,
         return CE_Failure;
     }
 
+    const unsigned int nUInt32Size = 4;
     for( unsigned iImg = 0, iBuf = 0;
-         iImg < nBlockXSize * (unsigned)sizeof(GDT_UInt32);
-         iImg += (unsigned)sizeof(GDT_UInt32), iBuf += (unsigned)nBytePerPixel )
+         iImg < nBlockXSize * nUInt32Size;
+         iImg += nUInt32Size, iBuf += (unsigned)nBytePerPixel )
     {
 #ifdef CPL_LSB
         ((GByte*) pImage)[iImg] = pReadBuf[iBuf + 2];
@@ -148,17 +149,16 @@ CPLErr MerisL2FlagBand::IReadBlock( CPL_UNUSED int nBlockXOff,
     return CE_None;
 }
 
-
 /************************************************************************/
 /* ==================================================================== */
-/*				EnvisatDataset				*/
+/*                              EnvisatDataset                          */
 /* ==================================================================== */
 /************************************************************************/
 
 class EnvisatDataset : public RawDataset
 {
     EnvisatFile *hEnvisatFile;
-    VSILFILE	*fpImage;
+    VSILFILE    *fpImage;
 
     int         nGCPCount;
     GDAL_GCP    *pasGCPList;
@@ -170,32 +170,31 @@ class EnvisatDataset : public RawDataset
 
     void        UnwrapGCPs();
 
-    void	CollectMetadata( EnvisatFile_HeaderFlag );
+    void        CollectMetadata( EnvisatFile_HeaderFlag );
     void        CollectDSDMetadata();
     void        CollectADSMetadata();
 
   public:
-    		EnvisatDataset();
-    	        ~EnvisatDataset();
-
-    virtual int    GetGCPCount();
-    virtual const char *GetGCPProjection();
-    virtual const GDAL_GCP *GetGCPs();
-    virtual char      **GetMetadataDomainList();
-    virtual char **GetMetadata( const char * pszDomain );
+                EnvisatDataset();
+    virtual ~EnvisatDataset();
 
+    virtual int    GetGCPCount() override;
+    virtual const char *GetGCPProjection() override;
+    virtual const GDAL_GCP *GetGCPs() override;
+    virtual char      **GetMetadataDomainList() override;
+    virtual char **GetMetadata( const char * pszDomain ) override;
 
     static GDALDataset *Open( GDALOpenInfo * );
 };
 
 /************************************************************************/
 /* ==================================================================== */
-/*				EnvisatDataset				*/
+/*                              EnvisatDataset                          */
 /* ==================================================================== */
 /************************************************************************/
 
 /************************************************************************/
-/*                            EnvisatDataset()                             */
+/*                            EnvisatDataset()                          */
 /************************************************************************/
 
 EnvisatDataset::EnvisatDataset() :
@@ -204,11 +203,10 @@ EnvisatDataset::EnvisatDataset() :
     nGCPCount(0),
     pasGCPList(NULL),
     papszTempMD(NULL)
-{
-}
+{}
 
 /************************************************************************/
-/*                            ~EnvisatDataset()                            */
+/*                            ~EnvisatDataset()                         */
 /************************************************************************/
 
 EnvisatDataset::~EnvisatDataset()
@@ -301,11 +299,12 @@ void EnvisatDataset::ScanForGCPs_ASAR()
         return;
 
 /* -------------------------------------------------------------------- */
-/*      Collect the first GCP set from each record.			*/
+/*      Collect the first GCP set from each record.                     */
 /* -------------------------------------------------------------------- */
-    GByte	abyRecord[521];
-    int  	nRange=0, nRangeOffset=0;
-    GUInt32 	unValue;
+    GByte abyRecord[521];
+    int nRange = 0;
+    int nRangeOffset = 0;
+    GUInt32 unValue;
 
     nGCPCount = 0;
     pasGCPList = (GDAL_GCP *) CPLCalloc(sizeof(GDAL_GCP),(nNumDSR+1) * 11);
@@ -441,7 +440,7 @@ void EnvisatDataset::ScanForGCPs_MERIS()
 
     for( ; true; nMDSIndex++ )
     {
-        char *pszDSType;
+        char *pszDSType = NULL;
         if( EnvisatFile_GetDatasetInfo( hEnvisatFile, nMDSIndex,
             NULL, &pszDSType, NULL, NULL, NULL, NULL, NULL ) == FAILURE )
         {
@@ -453,7 +452,7 @@ void EnvisatDataset::ScanForGCPs_MERIS()
     }
 
 /* -------------------------------------------------------------------- */
-/*      Get subset of TP ADS records matching the MDS records	*/
+/*      Get subset of TP ADS records matching the MDS records           */
 /* -------------------------------------------------------------------- */
 
     /* get the MDS line sampling time interval */
@@ -511,10 +510,10 @@ void EnvisatDataset::ScanForGCPs_MERIS()
     }
 
 /* -------------------------------------------------------------------- */
-/*      Collect the first GCP set from each record.			*/
+/*      Collect the first GCP set from each record.                     */
 /* -------------------------------------------------------------------- */
 
-    GByte	*pabyRecord = (GByte *) CPLMalloc(nDSRSize-13);
+    GByte *pabyRecord = (GByte *) CPLMalloc(nDSRSize-13);
 
     GUInt32 *tpLat = ((GUInt32*)pabyRecord) + nTPPerLine*0 ; /* latitude */
     GUInt32 *tpLon = ((GUInt32*)pabyRecord) + nTPPerLine*1 ; /* longitude */
@@ -667,7 +666,7 @@ char **EnvisatDataset::GetMetadata( const char * pszDomain )
 void EnvisatDataset::CollectDSDMetadata()
 
 {
-    char	*pszDSName, *pszFilename;
+    char *pszDSName, *pszFilename;
 
     for( int iDSD = 0;
          EnvisatFile_GetDatasetInfo( hEnvisatFile, iDSD, &pszDSName, NULL,
@@ -853,7 +852,7 @@ GDALDataset *EnvisatDataset::Open( GDALOpenInfo * poOpenInfo )
 /* -------------------------------------------------------------------- */
 /*      Try opening the dataset.                                        */
 /* -------------------------------------------------------------------- */
-    EnvisatFile	*hEnvisatFile;
+    EnvisatFile *hEnvisatFile = NULL;
     if( EnvisatFile_Open( &hEnvisatFile, poOpenInfo->pszFilename, "r" )
         == FAILURE )
         return NULL;
@@ -863,7 +862,7 @@ GDALDataset *EnvisatDataset::Open( GDALOpenInfo * poOpenInfo )
 /*      raster band.                                                    */
 /* -------------------------------------------------------------------- */
     int         dsr_size, num_dsr, ds_offset;
-    char        *pszDSType;
+    char        *pszDSType = NULL;
 
     int ds_index = 0;
     for( ; true; ds_index++ )
@@ -996,7 +995,7 @@ GDALDataset *EnvisatDataset::Open( GDALOpenInfo * poOpenInfo )
 /*      Scan for all datasets matching the reference dataset.           */
 /* -------------------------------------------------------------------- */
     int num_dsr2, dsr_size2, iBand = 0;
-    const char *pszDSName;
+    const char *pszDSName = NULL;
     char szBandName[128];
     bool bMiltiChannel;
 
@@ -1138,7 +1137,7 @@ GDALDataset *EnvisatDataset::Open( GDALOpenInfo * poOpenInfo )
 /* -------------------------------------------------------------------- */
     poDS->oOvManager.Initialize( poDS, poOpenInfo->pszFilename );
 
-    return( poDS );
+    return poDS;
 }
 
 /************************************************************************/
