@@ -1,5 +1,4 @@
 /******************************************************************************
- * $Id: ddffielddefn.cpp 33717 2016-03-14 06:29:14Z goatbar $
  *
  * Project:  ISO 8211 Access
  * Purpose:  Implements the DDFFieldDefn class.
@@ -27,11 +26,20 @@
  * DEALINGS IN THE SOFTWARE.
  ****************************************************************************/
 
+#include "cpl_port.h"
 #include "iso8211.h"
-#include "cpl_string.h"
-#include <ctype.h>
 
-CPL_CVSID("$Id: ddffielddefn.cpp 33717 2016-03-14 06:29:14Z goatbar $");
+#include <cctype>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+
+#include "cpl_conv.h"
+#include "cpl_error.h"
+#include "cpl_string.h"
+
+CPL_CVSID("$Id: ddffielddefn.cpp 36552 2016-11-29 06:01:45Z goatbar $");
 
 #define CPLE_DiscardedFormat   1301
 
@@ -39,12 +47,19 @@ CPL_CVSID("$Id: ddffielddefn.cpp 33717 2016-03-14 06:29:14Z goatbar $");
 /*                            DDFFieldDefn()                            */
 /************************************************************************/
 
-DDFFieldDefn::DDFFieldDefn()
-    : poModule(NULL), pszTag(NULL), _fieldName(NULL), _arrayDescr(NULL),
-      _formatControls(NULL), bRepeatingSubfields(FALSE), nFixedWidth(0),
-      _data_struct_code(dsc_elementary), _data_type_code(dtc_char_string),
-      nSubfieldCount(0), papoSubfields(NULL)
-{ }
+DDFFieldDefn::DDFFieldDefn() :
+    poModule(NULL),
+    pszTag(NULL),
+    _fieldName(NULL),
+    _arrayDescr(NULL),
+    _formatControls(NULL),
+    bRepeatingSubfields(FALSE),
+    nFixedWidth(0),
+    _data_struct_code(dsc_elementary),
+    _data_type_code(dtc_char_string),
+    nSubfieldCount(0),
+    papoSubfields(NULL)
+{}
 
 /************************************************************************/
 /*                           ~DDFFieldDefn()                            */
@@ -58,8 +73,7 @@ DDFFieldDefn::~DDFFieldDefn()
     CPLFree( _arrayDescr );
     CPLFree( _formatControls );
 
-    int i;
-    for( i = 0; i < nSubfieldCount; i++ )
+    for( int i = 0; i < nSubfieldCount; i++ )
         delete papoSubfields[i];
     CPLFree( papoSubfields );
 }
@@ -88,8 +102,8 @@ void DDFFieldDefn::AddSubfield( DDFSubfieldDefn *poNewSFDefn,
 
 {
     nSubfieldCount++;
-    papoSubfields = (DDFSubfieldDefn ** )
-        CPLRealloc( papoSubfields, sizeof(void*) * nSubfieldCount );
+    papoSubfields = static_cast<DDFSubfieldDefn **>(
+        CPLRealloc( papoSubfields, sizeof(void*) * nSubfieldCount ));
     papoSubfields[nSubfieldCount-1] = poNewSFDefn;
 
     if( bDontAddToFormat )
@@ -105,10 +119,10 @@ void DDFFieldDefn::AddSubfield( DDFSubfieldDefn *poNewSFDefn,
         _formatControls = CPLStrdup( "()" );
     }
 
-    int nOldLen = static_cast<int>(strlen(_formatControls));
+    const int nOldLen = static_cast<int>(strlen(_formatControls));
 
-    char *pszNewFormatControls = (char *)
-        CPLMalloc(nOldLen+3+strlen(poNewSFDefn->GetFormat()));
+    char *pszNewFormatControls = static_cast<char *>(
+        CPLMalloc(nOldLen+3+strlen(poNewSFDefn->GetFormat())));
 
     strcpy( pszNewFormatControls, _formatControls );
     pszNewFormatControls[nOldLen-1] = '\0';
@@ -150,9 +164,9 @@ int DDFFieldDefn::Create( const char *pszTagIn, const char *pszFieldName,
                           const char *pszFormat )
 
 {
-    CPLAssert( this->pszTag == NULL );
+    CPLAssert( pszTag == NULL );
     poModule = NULL;
-    this->pszTag = CPLStrdup( pszTagIn );
+    pszTag = CPLStrdup( pszTagIn );
     _fieldName = CPLStrdup( pszFieldName );
     _arrayDescr = CPLStrdup( pszDescription );
 
@@ -174,7 +188,7 @@ int DDFFieldDefn::Create( const char *pszTagIn, const char *pszFieldName,
 /*                         SetFormatControls()                          */
 /************************************************************************/
 
-void DDFFieldDefn::SetFormatControls(const char* pszVal)
+void DDFFieldDefn::SetFormatControls( const char* pszVal )
 {
     CPLFree(_formatControls);
     _formatControls = CPLStrdup(pszVal ? pszVal : "");
@@ -188,7 +202,7 @@ int DDFFieldDefn::GenerateDDREntry( DDFModule * poModuleIn, char **ppachData,
                                     int *pnLength )
 
 {
-    const int         iFDOffset = poModuleIn->GetFieldControlLength();
+    const int iFDOffset = poModuleIn->GetFieldControlLength();
     CPLAssert(iFDOffset >= 6 && iFDOffset <= 9);
     *pnLength = static_cast<int>(iFDOffset + strlen(_fieldName) + 1
         + strlen(_arrayDescr) + 1
@@ -202,7 +216,7 @@ int DDFFieldDefn::GenerateDDREntry( DDFModule * poModuleIn, char **ppachData,
     if( ppachData == NULL )
         return TRUE;
 
-    *ppachData = (char *) CPLMalloc( *pnLength+1 );
+    *ppachData = static_cast<char *>(CPLMalloc(*pnLength + 1));
 
     if( _data_struct_code == dsc_elementary )
         (*ppachData)[0] = '0';
@@ -267,8 +281,7 @@ int DDFFieldDefn::Initialize( DDFModule * poModuleIn,
                               const char * pachFieldArea )
 
 {
-    int         iFDOffset = poModuleIn->GetFieldControlLength();
-    int         nCharsConsumed;
+    int iFDOffset = poModuleIn->GetFieldControlLength();
 
     poModule = poModuleIn;
 
@@ -348,6 +361,7 @@ int DDFFieldDefn::Initialize( DDFModule * poModuleIn,
 /*      format statements.                                              */
 /* -------------------------------------------------------------------- */
 
+    int nCharsConsumed = 0;
     _fieldName =
         DDFFetchVariable( pachFieldArea + iFDOffset,
                           nFieldEntrySize - iFDOffset,
@@ -390,7 +404,7 @@ int DDFFieldDefn::Initialize( DDFModule * poModuleIn,
 /**
  * Write out field definition info to debugging file.
  *
- * A variety of information about this field definition, and all it's
+ * A variety of information about this field definition, and all its
  * subfields is written to the give debugging file handle.
  *
  * @param fp The standard IO file handle to write to.  i.e. stderr
@@ -426,7 +440,7 @@ void DDFFieldDefn::Dump( FILE * fp )
         break;
 
       default:
-        CPLAssert( FALSE );
+        CPLAssert( false );
         pszValue = "(unknown)";
     }
 
@@ -463,7 +477,7 @@ void DDFFieldDefn::Dump( FILE * fp )
         break;
 
       default:
-        CPLAssert( FALSE );
+        CPLAssert( false );
         pszValue = "(unknown)";
         break;
     }
@@ -483,8 +497,7 @@ void DDFFieldDefn::Dump( FILE * fp )
 int DDFFieldDefn::BuildSubfields()
 
 {
-    char        **papszSubfieldNames;
-    const char  *pszSublist = _arrayDescr;
+    const char *pszSublist = _arrayDescr;
 
 /* -------------------------------------------------------------------- */
 /*      It is valid to define a field with _arrayDesc                   */
@@ -500,7 +513,7 @@ int DDFFieldDefn::BuildSubfields()
 /*      '*' in the subfield list.                                       */
 /* -------------------------------------------------------------------- */
     if( strrchr(pszSublist, '*') != NULL )
-        pszSublist = strrchr(pszSublist,'*');
+        pszSublist = strrchr(pszSublist, '*');
 
 /* -------------------------------------------------------------------- */
 /*      Strip off the repeating marker, when it occurs, but mark our    */
@@ -515,13 +528,13 @@ int DDFFieldDefn::BuildSubfields()
 /* -------------------------------------------------------------------- */
 /*      split list of fields .                                          */
 /* -------------------------------------------------------------------- */
-    papszSubfieldNames = CSLTokenizeStringComplex( pszSublist, "!",
-                                                   FALSE, FALSE );
+    char **papszSubfieldNames =
+        CSLTokenizeStringComplex( pszSublist, "!", FALSE, FALSE );
 
 /* -------------------------------------------------------------------- */
 /*      minimally initialize the subfields.  More will be done later.   */
 /* -------------------------------------------------------------------- */
-    int nSFCount = CSLCount( papszSubfieldNames );
+    const int nSFCount = CSLCount( papszSubfieldNames );
     for( int iSF = 0; iSF < nSFCount; iSF++ )
     {
         DDFSubfieldDefn *poSFDefn = new DDFSubfieldDefn;
@@ -551,10 +564,9 @@ int DDFFieldDefn::BuildSubfields()
 char *DDFFieldDefn::ExtractSubstring( const char * pszSrc )
 
 {
-    int         nBracket=0, i;
-    char        *pszReturn;
-
-    for( i = 0;
+    int nBracket = 0;
+    int i = 0;  // Used after for.
+    for( ;
          pszSrc[i] != '\0' && (nBracket > 0 || pszSrc[i] != ',');
          i++ )
     {
@@ -564,6 +576,7 @@ char *DDFFieldDefn::ExtractSubstring( const char * pszSrc )
             nBracket--;
     }
 
+    char *pszReturn = NULL;
     if( pszSrc[0] == '(' )
     {
         pszReturn = CPLStrdup( pszSrc + 1 );
@@ -585,30 +598,29 @@ char *DDFFieldDefn::ExtractSubstring( const char * pszSrc )
 char *DDFFieldDefn::ExpandFormat( const char * pszSrc )
 
 {
-    size_t      nDestMax = 32;
-    char       *pszDest = (char *) CPLMalloc(nDestMax+1);
-    size_t      iSrc, iDst;
-    int         nRepeat = 0;
+    size_t nDestMax = 32;
+    char *pszDest = static_cast<char *>(CPLMalloc(nDestMax + 1));
+    int nRepeat = 0;
 
-    iSrc = 0;
-    iDst = 0;
+    size_t iSrc = 0;
+    size_t iDst = 0;
     pszDest[0] = '\0';
 
     while( pszSrc[iSrc] != '\0' )
     {
-        /* This is presumably an extra level of brackets around some
-           binary stuff related to rescanning which we don't care to do
-           (see 6.4.3.3 of the standard.  We just strip off the extra
-           layer of brackets */
+        // This is presumably an extra level of brackets around some
+        // binary stuff related to rescanning which we don't care to do
+        // (see 6.4.3.3 of the standard.  We just strip off the extra
+        // layer of brackets.
         if( (iSrc == 0 || pszSrc[iSrc-1] == ',') && pszSrc[iSrc] == '(' )
         {
-            char       *pszContents = ExtractSubstring( pszSrc+iSrc );
-            char       *pszExpandedContents = ExpandFormat( pszContents );
+            char *pszContents = ExtractSubstring( pszSrc+iSrc );
+            char *pszExpandedContents = ExpandFormat( pszContents );
 
             if( strlen(pszExpandedContents) + strlen(pszDest) + 1 > nDestMax )
             {
                 nDestMax = 2 * (strlen(pszExpandedContents) + strlen(pszDest));
-                pszDest = (char *) CPLRealloc(pszDest,nDestMax+1);
+                pszDest = static_cast<char *>(CPLRealloc(pszDest,nDestMax + 1));
             }
 
             strcat( pszDest, pszExpandedContents );
@@ -620,27 +632,29 @@ char *DDFFieldDefn::ExpandFormat( const char * pszSrc )
             CPLFree( pszExpandedContents );
         }
 
-        /* this is a repeated subclause */
+        // This is a repeated subclause.
         else if( (iSrc == 0 || pszSrc[iSrc-1] == ',')
                  && isdigit(pszSrc[iSrc]) )
         {
-            const char *pszNext;
             nRepeat = atoi(pszSrc+iSrc);
 
-            // skip over repeat count.
-            for( pszNext = pszSrc+iSrc; isdigit(*pszNext); pszNext++ )
+            // Skip over repeat count.
+            const char *pszNext = pszSrc + iSrc;  // Used after for.
+            for( ; isdigit(*pszNext); pszNext++ )
                 iSrc++;
 
-            char       *pszContents = ExtractSubstring( pszNext );
-            char       *pszExpandedContents = ExpandFormat( pszContents );
+            char *pszContents = ExtractSubstring( pszNext );
+            char *pszExpandedContents = ExpandFormat( pszContents );
 
             for( int i = 0; i < nRepeat; i++ )
             {
-                if( strlen(pszExpandedContents) + strlen(pszDest) + 1 + 1 > nDestMax )
+                if( strlen(pszExpandedContents) + strlen(pszDest) + 1 + 1 >
+                    nDestMax )
                 {
                     nDestMax =
                         2 * (strlen(pszExpandedContents) + strlen(pszDest) + 1);
-                    pszDest = (char *) CPLRealloc(pszDest,nDestMax+1);
+                    pszDest =
+                        static_cast<char *>(CPLRealloc(pszDest,nDestMax + 1));
                 }
 
                 strcat( pszDest, pszExpandedContents );
@@ -663,7 +677,7 @@ char *DDFFieldDefn::ExpandFormat( const char * pszSrc )
             if( iDst+1 >= nDestMax )
             {
                 nDestMax = 2 * iDst;
-                pszDest = (char *) CPLRealloc(pszDest,nDestMax);
+                pszDest = static_cast<char *>(CPLRealloc(pszDest, nDestMax));
             }
 
             pszDest[iDst++] = pszSrc[iSrc++];
@@ -685,9 +699,6 @@ char *DDFFieldDefn::ExpandFormat( const char * pszSrc )
 int DDFFieldDefn::ApplyFormats()
 
 {
-    char        *pszFormatList;
-    char        **papszFormatItems;
-
 /* -------------------------------------------------------------------- */
 /*      Verify that the format string is contained within brackets.     */
 /* -------------------------------------------------------------------- */
@@ -695,7 +706,7 @@ int DDFFieldDefn::ApplyFormats()
         || _formatControls[0] != '('
         || _formatControls[strlen(_formatControls)-1] != ')' )
     {
-        CPLError( CE_Warning, (CPLErrorNum)CPLE_DiscardedFormat,
+        CPLError( CE_Warning, static_cast<CPLErrorNum>(CPLE_DiscardedFormat),
                   "Format controls for `%s' field missing brackets:%s",
                   pszTag, _formatControls );
 
@@ -706,12 +717,12 @@ int DDFFieldDefn::ApplyFormats()
 /*      Duplicate the string, and strip off the brackets.               */
 /* -------------------------------------------------------------------- */
 
-    pszFormatList = ExpandFormat( _formatControls );
+    char *pszFormatList = ExpandFormat( _formatControls );
 
 /* -------------------------------------------------------------------- */
 /*      Tokenize based on commas.                                       */
 /* -------------------------------------------------------------------- */
-    papszFormatItems =
+    char **papszFormatItems =
         CSLTokenizeStringComplex(pszFormatList, ",", FALSE, FALSE );
 
     CPLFree( pszFormatList );
@@ -719,15 +730,13 @@ int DDFFieldDefn::ApplyFormats()
 /* -------------------------------------------------------------------- */
 /*      Apply the format items to subfields.                            */
 /* -------------------------------------------------------------------- */
-    int iFormatItem;
+    int iFormatItem = 0;  // Used after for.
 
-    for( iFormatItem = 0;
+    for( ;
          papszFormatItems[iFormatItem] != NULL;
          iFormatItem++ )
     {
-        const char      *pszPastPrefix;
-
-        pszPastPrefix = papszFormatItems[iFormatItem];
+        const char *pszPastPrefix = papszFormatItems[iFormatItem];
         while( *pszPastPrefix >= '0' && *pszPastPrefix <= '9' )
             pszPastPrefix++;
 
@@ -739,7 +748,7 @@ int DDFFieldDefn::ApplyFormats()
 
         if( iFormatItem >= nSubfieldCount )
         {
-            CPLError( CE_Warning, (CPLErrorNum)CPLE_DiscardedFormat,
+          CPLError( CE_Warning, static_cast<CPLErrorNum>(CPLE_DiscardedFormat),
                       "Got more formats than subfields for field `%s'.",
                       pszTag );
             break;
@@ -759,7 +768,7 @@ int DDFFieldDefn::ApplyFormats()
 
     if( iFormatItem < nSubfieldCount )
     {
-        CPLError( CE_Warning, (CPLErrorNum)CPLE_DiscardedFormat,
+        CPLError( CE_Warning, static_cast<CPLErrorNum>(CPLE_DiscardedFormat),
                   "Got less formats than subfields for field `%s'.",
                   pszTag );
         return FALSE;
@@ -778,7 +787,9 @@ int DDFFieldDefn::ApplyFormats()
             break;
         }
         else
+        {
             nFixedWidth += papoSubfields[i]->GetWidth();
+        }
     }
 
     return TRUE;
@@ -789,14 +800,13 @@ int DDFFieldDefn::ApplyFormats()
 /************************************************************************/
 
 /**
- * Find a subfield definition by it's mnemonic tag.
+ * Find a subfield definition by its mnemonic tag.
  *
  * @param pszMnemonic The name of the field.
  *
  * @return The subfield pointer, or NULL if there isn't any such subfield.
  */
 
-
 DDFSubfieldDefn *DDFFieldDefn::FindSubfieldDefn( const char * pszMnemonic )
 
 {
@@ -812,7 +822,7 @@ DDFSubfieldDefn *DDFFieldDefn::FindSubfieldDefn( const char * pszMnemonic )
 /************************************************************************/
 /*                            GetSubfield()                             */
 /*                                                                      */
-/*      Fetch a subfield by it's index.                                 */
+/*      Fetch a subfield by its index.                                 */
 /************************************************************************/
 
 /**
@@ -828,7 +838,7 @@ DDFSubfieldDefn *DDFFieldDefn::GetSubfield( int i )
 {
     if( i < 0 || i >= nSubfieldCount )
     {
-        CPLAssert( FALSE );
+        CPLAssert( false );
         return NULL;
     }
 
@@ -849,12 +859,11 @@ char *DDFFieldDefn::GetDefaultValue( int *pnSize )
 /* -------------------------------------------------------------------- */
 /*      Loop once collecting the sum of the subfield lengths.           */
 /* -------------------------------------------------------------------- */
-    int iSubfield;
     int nTotalSize = 0;
 
-    for( iSubfield = 0; iSubfield < nSubfieldCount; iSubfield++ )
+    for( int iSubfield = 0; iSubfield < nSubfieldCount; iSubfield++ )
     {
-        int nSubfieldSize;
+        int nSubfieldSize = 0;
 
         if( !papoSubfields[iSubfield]->GetDefaultValue( NULL, 0,
                                                         &nSubfieldSize ) )
@@ -865,7 +874,7 @@ char *DDFFieldDefn::GetDefaultValue( int *pnSize )
 /* -------------------------------------------------------------------- */
 /*      Allocate buffer.                                                */
 /* -------------------------------------------------------------------- */
-    char *pachData = (char *) CPLMalloc( nTotalSize );
+    char *pachData = static_cast<char *>(CPLMalloc( nTotalSize ));
 
     if( pnSize != NULL )
         *pnSize = nTotalSize;
@@ -874,14 +883,14 @@ char *DDFFieldDefn::GetDefaultValue( int *pnSize )
 /*      Loop again, collecting actual default values.                   */
 /* -------------------------------------------------------------------- */
     int nOffset = 0;
-    for( iSubfield = 0; iSubfield < nSubfieldCount; iSubfield++ )
+    for( int iSubfield = 0; iSubfield < nSubfieldCount; iSubfield++ )
     {
         int nSubfieldSize;
 
         if( !papoSubfields[iSubfield]->GetDefaultValue(
                 pachData + nOffset, nTotalSize - nOffset, &nSubfieldSize ) )
         {
-            CPLAssert( FALSE );
+            CPLAssert( false );
             return NULL;
         }
 
