@@ -1,5 +1,4 @@
 /******************************************************************************
- * $Id: ogr_srs_panorama.cpp 33631 2016-03-04 06:28:09Z goatbar $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  OGRSpatialReference translation to/from "Panorama" GIS
@@ -30,14 +29,14 @@
  ****************************************************************************/
 
 #include "ogr_spatialref.h"
-#include "ogr_p.h"
 #include "cpl_conv.h"
 #include "cpl_csv.h"
+#include "ogr_p.h"
 
-CPL_CVSID("$Id: ogr_srs_panorama.cpp 33631 2016-03-04 06:28:09Z goatbar $");
+CPL_CVSID("$Id: ogr_srs_panorama.cpp 36238 2016-11-14 20:52:13Z goatbar $");
 
-#define TO_DEGREES 57.2957795130823208766
-#define TO_RADIANS 0.017453292519943295769
+static const double TO_DEGREES = 57.2957795130823208766;
+static const double TO_RADIANS = 0.017453292519943295769;
 
 // XXX: this macro computes zone number from the central meridian parameter.
 // Note, that "Panorama" parameters are set in radians.
@@ -45,52 +44,56 @@ CPL_CVSID("$Id: ogr_srs_panorama.cpp 33631 2016-03-04 06:28:09Z goatbar $");
 //
 //              zone = (central_meridian + 3) / 6
 //
-#define TO_ZONE(x) (((x) + 0.05235987755982989) / 0.1047197551196597 + 0.5)
+static int TO_ZONE( double x )
+{
+  return
+      static_cast<int>((x + 0.05235987755982989) / 0.1047197551196597 + 0.5);
+}
 
 /************************************************************************/
 /*  "Panorama" projection codes.                                        */
 /************************************************************************/
 
-#define PAN_PROJ_NONE   -1L
-#define PAN_PROJ_TM     1L      // Gauss-Kruger (Transverse Mercator)
-#define PAN_PROJ_LCC    2L      // Lambert Conformal Conic 2SP
-#define PAN_PROJ_STEREO 5L      // Stereographic
-#define PAN_PROJ_AE     6L      // Azimuthal Equidistant (Postel)
-#define PAN_PROJ_MERCAT 8L      // Mercator
-#define PAN_PROJ_POLYC  10L     // Polyconic
-#define PAN_PROJ_PS     13L     // Polar Stereographic
-#define PAN_PROJ_GNOMON 15L     // Gnomonic
-#define PAN_PROJ_UTM    17L     // Universal Transverse Mercator (UTM)
-#define PAN_PROJ_WAG1   18L     // Wagner I (Kavraisky VI)
-#define PAN_PROJ_MOLL   19L     // Mollweide
-#define PAN_PROJ_EC     20L     // Equidistant Conic
-#define PAN_PROJ_LAEA   24L     // Lambert Azimuthal Equal Area
-#define PAN_PROJ_EQC    27L     // Equirectangular
-#define PAN_PROJ_CEA    28L     // Cylindrical Equal Area (Lambert)
-#define PAN_PROJ_IMWP   29L     // International Map of the World Polyconic
-#define PAN_PROJ_MILLER 34L     // Miller
+static const long PAN_PROJ_NONE   = -1L;
+static const long PAN_PROJ_TM     = 1L;   // Gauss-Kruger (Transverse Mercator)
+static const long PAN_PROJ_LCC    = 2L;   // Lambert Conformal Conic 2SP
+static const long PAN_PROJ_STEREO = 5L;   // Stereographic
+static const long PAN_PROJ_AE     = 6L;   // Azimuthal Equidistant (Postel)
+static const long PAN_PROJ_MERCAT = 8L;   // Mercator
+static const long PAN_PROJ_POLYC  = 10L;  // Polyconic
+static const long PAN_PROJ_PS     = 13L;  // Polar Stereographic
+static const long PAN_PROJ_GNOMON = 15L;  // Gnomonic
+static const long PAN_PROJ_UTM    = 17L;  // Universal Transverse Mercator (UTM)
+static const long PAN_PROJ_WAG1   = 18L;  // Wagner I (Kavraisky VI)
+static const long PAN_PROJ_MOLL   = 19L;  // Mollweide
+static const long PAN_PROJ_EC     = 20L;  // Equidistant Conic
+static const long PAN_PROJ_LAEA   = 24L;  // Lambert Azimuthal Equal Area
+static const long PAN_PROJ_EQC    = 27L;  // Equirectangular
+static const long PAN_PROJ_CEA    = 28L;  // Cylindrical Equal Area (Lambert)
+static const long PAN_PROJ_IMWP   = 29L;  // International Map of the World Polyconic
+static const long PAN_PROJ_MILLER = 34L;  // Miller
 /************************************************************************/
 /*  "Panorama" datum codes.                                             */
 /************************************************************************/
 
-#define PAN_DATUM_NONE      -1L
-#define PAN_DATUM_PULKOVO42 1L  // Pulkovo 1942
-#define PAN_DATUM_WGS84     2L  // WGS84
+static const long PAN_DATUM_NONE      = -1L;
+static const long PAN_DATUM_PULKOVO42 = 1L;  // Pulkovo 1942
+static const long PAN_DATUM_WGS84     = 2L;  // WGS84
 
 /************************************************************************/
 /*  "Panorama" ellipsoid codes.                                         */
 /************************************************************************/
 
-#define PAN_ELLIPSOID_NONE          -1L
-#define PAN_ELLIPSOID_KRASSOVSKY    1L  // Krassovsky, 1940
-#define PAN_ELLIPSOID_WGS72         2L  // WGS, 1972
-#define PAN_ELLIPSOID_INT1924       3L  // International, 1924 (Hayford, 1909)
-#define PAN_ELLIPSOID_CLARCKE1880   4L  // Clarke, 1880
-#define PAN_ELLIPSOID_CLARCKE1866   5L  // Clarke, 1866 (NAD1927)
-#define PAN_ELLIPSOID_EVEREST1830   6L  // Everest, 1830
-#define PAN_ELLIPSOID_BESSEL1841    7L  // Bessel, 1841
-#define PAN_ELLIPSOID_AIRY1830      8L  // Airy, 1830
-#define PAN_ELLIPSOID_WGS84         9L  // WGS, 1984 (GPS)
+static const long PAN_ELLIPSOID_NONE        = -1L;
+static const long PAN_ELLIPSOID_KRASSOVSKY  = 1L;  // Krassovsky, 1940
+// static const long PAN_ELLIPSOID_WGS72       = 2L;  // WGS, 1972
+// static const long PAN_ELLIPSOID_INT1924     = 3L;  // International, 1924 (Hayford, 1909)
+// static const long PAN_ELLIPSOID_CLARCKE1880 = 4L;  // Clarke, 1880
+// static const long PAN_ELLIPSOID_CLARCKE1866 = 5L;  // Clarke, 1866 (NAD1927)
+// static const long PAN_ELLIPSOID_EVEREST1830 = 6L;  // Everest, 1830
+// static const long PAN_ELLIPSOID_BESSEL1841  = 7L;  // Bessel, 1841
+// static const long PAN_ELLIPSOID_AIRY1830    = 8L;  // Airy, 1830
+static const long PAN_ELLIPSOID_WGS84       = 9L;  // WGS, 1984 (GPS)
 
 /************************************************************************/
 /*  Correspondence between "Panorama" and EPSG datum codes.             */
@@ -141,12 +144,18 @@ static const int aoEllips[] =
     7003   // Australian National, 1965
 };
 
-#define NUMBER_OF_ELLIPSOIDS    static_cast<int>(sizeof(aoEllips)/sizeof(aoEllips[0]))
+static const int NUMBER_OF_ELLIPSOIDS =
+    static_cast<int>(sizeof(aoEllips)/sizeof(aoEllips[0]));
 
 /************************************************************************/
 /*                        OSRImportFromPanorama()                       */
 /************************************************************************/
 
+/** Import coordinate system from "Panorama" GIS projection definition.
+ *
+ * See OGRSpatialReference::importFromPanorama()
+ */
+
 OGRErr OSRImportFromPanorama( OGRSpatialReferenceH hSRS,
                               long iProjSys, long iDatum, long iEllips,
                               double *padfPrjParams )
@@ -154,9 +163,10 @@ OGRErr OSRImportFromPanorama( OGRSpatialReferenceH hSRS,
 {
     VALIDATE_POINTER1( hSRS, "OSRImportFromPanorama", OGRERR_FAILURE );
 
-    return ((OGRSpatialReference *) hSRS)->importFromPanorama( iProjSys,
-                                                               iDatum,iEllips,
-                                                               padfPrjParams );
+    return reinterpret_cast<OGRSpatialReference *>(hSRS)->
+        importFromPanorama( iProjSys,
+                            iDatum, iEllips,
+                            padfPrjParams );
 }
 
 /************************************************************************/
@@ -248,16 +258,14 @@ OGRErr OGRSpatialReference::importFromPanorama( long iProjSys, long iDatum,
 /* -------------------------------------------------------------------- */
 /*      Use safe defaults if projection parameters are not supplied.    */
 /* -------------------------------------------------------------------- */
-    int bProjAllocated = false;
+    bool bProjAllocated = false;
 
     if( padfPrjParams == NULL )
     {
-        int     i;
-
-        padfPrjParams = (double *)CPLMalloc( 8 * sizeof(double) );
-        if ( !padfPrjParams )
+        padfPrjParams = static_cast<double *>(CPLMalloc(8 * sizeof(double)));
+        if( !padfPrjParams )
             return OGRERR_NOT_ENOUGH_MEMORY;
-        for ( i = 0; i < 7; i++ )
+        for( int i = 0; i < 7; i++ )
             padfPrjParams[i] = 0.0;
         bProjAllocated = true;
     }
@@ -265,19 +273,17 @@ OGRErr OGRSpatialReference::importFromPanorama( long iProjSys, long iDatum,
 /* -------------------------------------------------------------------- */
 /*      Operate on the basis of the projection code.                    */
 /* -------------------------------------------------------------------- */
-    switch ( iProjSys )
+    switch( iProjSys )
     {
         case PAN_PROJ_NONE:
             break;
 
         case PAN_PROJ_UTM:
             {
-                int nZone;
-
-                if ( padfPrjParams[7] == 0.0 )
-                    nZone = (int) TO_ZONE(padfPrjParams[3]);
-                else
-                    nZone = (int) padfPrjParams[7];
+                const int nZone =
+                    padfPrjParams[7] == 0.0
+                    ? TO_ZONE(padfPrjParams[3])
+                    : static_cast<int>(padfPrjParams[7]);
 
                 // XXX: no way to determine south hemisphere. Always assume
                 // northern hemisphere.
@@ -332,18 +338,18 @@ OGRErr OGRSpatialReference::importFromPanorama( long iProjSys, long iDatum,
                 // parameter, because usually it is not contained in the
                 // "Panorama" projection definition.
                 // FIXME: what to do with negative values?
-                int    nZone;
-                double  dfCenterLong;
+                int nZone = 0;
+                double dfCenterLong = 0.0;
 
-                if ( padfPrjParams[7] == 0.0 )
+                if( padfPrjParams[7] == 0.0 )
                 {
-                    nZone = (int)TO_ZONE(padfPrjParams[3]);
+                    nZone = TO_ZONE(padfPrjParams[3]);
                     dfCenterLong = TO_DEGREES * padfPrjParams[3];
                 }
                 else
                 {
-                    nZone = (int) padfPrjParams[7];
-                    dfCenterLong = 6 * (double)nZone - 3;
+                    nZone = static_cast<int>(padfPrjParams[7]);
+                    dfCenterLong = 6.0 * nZone - 3.0;
                 }
 
                 padfPrjParams[5] = nZone * 1000000.0 + 500000.0;
@@ -415,59 +421,58 @@ OGRErr OGRSpatialReference::importFromPanorama( long iProjSys, long iDatum,
             SetLocalCS( CPLString().Printf("\"Panorama\" projection number %ld",
                                    iProjSys) );
             break;
-
     }
 
 /* -------------------------------------------------------------------- */
 /*      Try to translate the datum/spheroid.                            */
 /* -------------------------------------------------------------------- */
 
-    if ( !IsLocal() )
+    if( !IsLocal() )
     {
-        if ( iDatum > 0 && iDatum < NUMBER_OF_DATUMS && aoDatums[iDatum] )
+        if( iDatum > 0 && iDatum < NUMBER_OF_DATUMS && aoDatums[iDatum] )
         {
             OGRSpatialReference oGCS;
             oGCS.importFromEPSG( aoDatums[iDatum] );
             CopyGeogCSFrom( &oGCS );
         }
-
-        else if ( iEllips > 0
-                  && iEllips < NUMBER_OF_ELLIPSOIDS
-                  && aoEllips[iEllips] )
+        else if( iEllips > 0
+                 && iEllips < NUMBER_OF_ELLIPSOIDS
+                 && aoEllips[iEllips] )
         {
-            char    *pszName = NULL;
-            double  dfSemiMajor, dfInvFlattening;
+            char *pszName = NULL;
+            double dfSemiMajor = 0.0;
+            double dfInvFlattening = 0.0;
 
-            if ( OSRGetEllipsoidInfo( aoEllips[iEllips], &pszName,
-                            &dfSemiMajor, &dfInvFlattening ) == OGRERR_NONE )
+            if( OSRGetEllipsoidInfo( aoEllips[iEllips], &pszName,
+                                     &dfSemiMajor,
+                                     &dfInvFlattening ) == OGRERR_NONE )
             {
-                SetGeogCS( CPLString().Printf(
-                            "Unknown datum based upon the %s ellipsoid",
-                            pszName ),
-                           CPLString().Printf(
-                            "Not specified (based on %s spheroid)", pszName ),
-                           pszName, dfSemiMajor, dfInvFlattening,
-                           NULL, 0.0, NULL, 0.0 );
+                SetGeogCS(
+                   CPLString().Printf(
+                       "Unknown datum based upon the %s ellipsoid",
+                       pszName ),
+                   CPLString().Printf(
+                       "Not specified (based on %s spheroid)", pszName ),
+                   pszName, dfSemiMajor, dfInvFlattening,
+                   NULL, 0.0, NULL, 0.0 );
                 SetAuthority( "SPHEROID", "EPSG", aoEllips[iEllips] );
             }
             else
             {
                 CPLError( CE_Warning, CPLE_AppDefined,
-                          "Failed to lookup ellipsoid code %ld, likely due to"
-                          " missing GDAL gcs.csv\n"
-                          " file.  Falling back to use Pulkovo 42.", iEllips );
+                          "Failed to lookup ellipsoid code %ld, likely due to "
+                          "missing GDAL gcs.csv "
+                          "file.  Falling back to use Pulkovo 42.", iEllips );
                 SetWellKnownGeogCS( "EPSG:4284" );
             }
 
-            if ( pszName )
-                CPLFree( pszName );
+            CPLFree( pszName );
         }
-
         else
         {
             CPLError( CE_Warning, CPLE_AppDefined,
-                      "Wrong datum code %ld. Supported datums are 1--%ld only.\n"
-                      "Falling back to use Pulkovo 42.",
+                      "Wrong datum code %ld. Supported datums are 1--%ld "
+                      "only.  Falling back to use Pulkovo 42.",
                       iDatum, NUMBER_OF_DATUMS - 1 );
             SetWellKnownGeogCS( "EPSG:4284" );
         }
@@ -481,7 +486,7 @@ OGRErr OGRSpatialReference::importFromPanorama( long iProjSys, long iDatum,
 
     FixupOrdering();
 
-    if ( bProjAllocated && padfPrjParams )
+    if( bProjAllocated && padfPrjParams )
         CPLFree( padfPrjParams );
 
     return OGRERR_NONE;
@@ -491,6 +496,11 @@ OGRErr OGRSpatialReference::importFromPanorama( long iProjSys, long iDatum,
 /*                      OSRExportToPanorama()                           */
 /************************************************************************/
 
+/** Export coordinate system in "Panorama" GIS projection definition.
+ *
+ * See OGRSpatialReference::exportToPanorama()
+ */
+
 OGRErr OSRExportToPanorama( OGRSpatialReferenceH hSRS,
                             long *piProjSys, long *piDatum, long *piEllips,
                             long *piZone, double *padfPrjParams )
@@ -502,10 +512,11 @@ OGRErr OSRExportToPanorama( OGRSpatialReferenceH hSRS,
     VALIDATE_POINTER1( piEllips, "OSRExportToPanorama", OGRERR_FAILURE );
     VALIDATE_POINTER1( padfPrjParams, "OSRExportToPanorama", OGRERR_FAILURE );
 
-    return ((OGRSpatialReference *) hSRS)->exportToPanorama( piProjSys,
-                                                             piDatum, piEllips,
-                                                             piZone,
-                                                             padfPrjParams );
+    return reinterpret_cast<OGRSpatialReference *>(hSRS)->
+        exportToPanorama( piProjSys,
+                          piDatum, piEllips,
+                          piZone,
+                          padfPrjParams );
 }
 
 /************************************************************************/
@@ -543,25 +554,24 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
 {
     CPLAssert( padfPrjParams );
 
-    const char  *pszProjection = GetAttrValue("PROJECTION");
+    const char *pszProjection = GetAttrValue("PROJECTION");
 
 /* -------------------------------------------------------------------- */
 /*      Fill all projection parameters with zero.                       */
 /* -------------------------------------------------------------------- */
-    int     i;
-
     *piDatum = 0L;
     *piEllips = 0L;
     *piZone = 0L;
-    for ( i = 0; i < 7; i++ )
+    for( int i = 0; i < 7; i++ )
         padfPrjParams[i] = 0.0;
 
 /* ==================================================================== */
 /*      Handle the projection definition.                               */
 /* ==================================================================== */
     if( IsLocal() )
+    {
         *piProjSys = PAN_PROJ_NONE;
-
+    }
     else if( pszProjection == NULL )
     {
 #ifdef DEBUG
@@ -570,7 +580,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
 #endif
         *piProjSys = PAN_PROJ_NONE;
     }
-
     else if( EQUAL(pszProjection, SRS_PT_MERCATOR_1SP) )
     {
         *piProjSys = PAN_PROJ_MERCAT;
@@ -582,7 +591,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_POLAR_STEREOGRAPHIC) )
     {
         *piProjSys = PAN_PROJ_PS;
@@ -594,7 +602,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_POLYCONIC) )
     {
         *piProjSys = PAN_PROJ_POLYC;
@@ -605,7 +612,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_EQUIDISTANT_CONIC) )
     {
         *piProjSys = PAN_PROJ_EC;
@@ -620,7 +626,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_LAMBERT_CONFORMAL_CONIC_2SP) )
     {
         *piProjSys = PAN_PROJ_LCC;
@@ -635,10 +640,9 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_TRANSVERSE_MERCATOR) )
     {
-        int bNorth;
+        int bNorth = FALSE;
 
         *piZone = GetUTMZone( &bNorth );
 
@@ -663,14 +667,12 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
                 GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
         }
     }
-
     else if( EQUAL(pszProjection, SRS_PT_WAGNER_I) )
     {
         *piProjSys = PAN_PROJ_WAG1;
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_STEREOGRAPHIC) )
     {
         *piProjSys = PAN_PROJ_STEREO;
@@ -682,7 +684,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_AZIMUTHAL_EQUIDISTANT) )
     {
         *piProjSys = PAN_PROJ_AE;
@@ -693,7 +694,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_GNOMONIC) )
     {
         *piProjSys = PAN_PROJ_GNOMON;
@@ -704,7 +704,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_MOLLWEIDE) )
     {
         *piProjSys = PAN_PROJ_MOLL;
@@ -713,7 +712,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_LAMBERT_AZIMUTHAL_EQUAL_AREA) )
     {
         *piProjSys = PAN_PROJ_LAEA;
@@ -724,7 +722,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_EQUIRECTANGULAR) )
     {
         *piProjSys = PAN_PROJ_EQC;
@@ -735,7 +732,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_CYLINDRICAL_EQUAL_AREA) )
     {
         *piProjSys = PAN_PROJ_CEA;
@@ -746,7 +742,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     else if( EQUAL(pszProjection, SRS_PT_IMW_POLYCONIC) )
     {
         *piProjSys = PAN_PROJ_IMWP;
@@ -759,7 +754,6 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         padfPrjParams[5] = GetNormProjParm( SRS_PP_FALSE_EASTING, 0.0 );
         padfPrjParams[6] = GetNormProjParm( SRS_PP_FALSE_NORTHING, 0.0 );
     }
-
     // Projection unsupported by "Panorama" GIS
     else
     {
@@ -772,14 +766,14 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
 /* -------------------------------------------------------------------- */
 /*      Translate the datum.                                            */
 /* -------------------------------------------------------------------- */
-    const char  *pszDatum = GetAttrValue( "DATUM" );
+    const char *pszDatum = GetAttrValue( "DATUM" );
 
-    if ( pszDatum == NULL )
+    if( pszDatum == NULL )
     {
         *piDatum = PAN_DATUM_NONE;
         *piEllips = PAN_ELLIPSOID_NONE;
     }
-    else if ( EQUAL( pszDatum, "Pulkovo_1942" ) )
+    else if( EQUAL( pszDatum, "Pulkovo_1942" ) )
     {
         *piDatum = PAN_DATUM_PULKOVO42;
         *piEllips = PAN_ELLIPSOID_KRASSOVSKY;
@@ -790,11 +784,11 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
         *piEllips = PAN_ELLIPSOID_WGS84;
     }
 
-    // If not found well known datum, translate ellipsoid
+    // If not found well known datum, translate ellipsoid.
     else
     {
-        double      dfSemiMajor = GetSemiMajor();
-        double      dfInvFlattening = GetInvFlattening();
+        const double dfSemiMajor = GetSemiMajor();
+        const double dfInvFlattening = GetInvFlattening();
 
 #ifdef DEBUG
         CPLDebug( "OSR_Panorama",
@@ -802,17 +796,18 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
                   "Trying to translate an ellipsoid definition.", pszDatum );
 #endif
 
-        for ( i = 0; i < NUMBER_OF_ELLIPSOIDS; i++ )
+        int i = 0;  // Used after for.
+        for( ; i < NUMBER_OF_ELLIPSOIDS; i++ )
         {
-            if ( aoEllips[i] )
+            if( aoEllips[i] )
             {
-                double  dfSM = 0.0;
-                double  dfIF = 1.0;
+                double dfSM = 0.0;
+                double dfIF = 1.0;
 
-                if ( OSRGetEllipsoidInfo( aoEllips[i], NULL,
-                                          &dfSM, &dfIF ) == OGRERR_NONE
-                     && CPLIsEqual(dfSemiMajor, dfSM)
-                     && CPLIsEqual(dfInvFlattening, dfIF) )
+                if( OSRGetEllipsoidInfo( aoEllips[i], NULL,
+                                         &dfSM, &dfIF ) == OGRERR_NONE
+                    && CPLIsEqual(dfSemiMajor, dfSM)
+                    && CPLIsEqual(dfInvFlattening, dfIF) )
                 {
                     *piEllips = i;
                     break;
@@ -820,7 +815,7 @@ OGRErr OGRSpatialReference::exportToPanorama( long *piProjSys, long *piDatum,
             }
         }
 
-        if ( i == NUMBER_OF_ELLIPSOIDS )    // Didn't found matches.
+        if( i == NUMBER_OF_ELLIPSOIDS )  // Didn't found matches.
         {
 #ifdef DEBUG
             CPLDebug( "OSR_Panorama",
